# HunabKu  / Servidor De Datos /  Maya - padre de todos los Dioses
PDBS (Paper DataBase Server)
PDBL  (Paper DataBase Loader)
PDBM (Paper DataBase Manager) (manejar colecciones - CRUD)

# Dependencies
* Install node js
* Apidocjs https://github.com/apidoc/apidoc 
* The other dependecies can be installed with pip installing this package.

Version 0.0.1-alpha Notes
* Plugin system implemented
* Apidoc support
* Plugins for GSLookUp, GSQuery and GSCites im package Moai craeted
* setup.py and requerements with fixed versions
* Old PDBServer completed removed
* Hunabku supports custom JSON encoder 
* Support to check syntax of Apidocs in plugins before load it, if it fails, plugin is not loaded
* Support for decorator in methods to create the endpoints
* Added plugin por apidoc
* Added support to check if an endpoint already exists



